<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 9.7.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

if ( ! comments_open() ) {
	return;
}

?>
<div id="reviews">
	<div id="comments" class="comments-area stm_woo_comments">
		<?php if ( have_comments() ) : ?>

			<ul class="comment-list list-unstyled">
				<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>
			</ul>

			<?php
			if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
				echo '<nav class="woocommerce-pagination">';
				paginate_comments_links(
					apply_filters(
						'woocommerce_comment_pagination_args',
						array(
							'prev_text' => '&larr;',
							'next_text' => '&rarr;',
							'type'      => 'list',
						)
					)
				);
				echo '</nav>';
			endif;
			?>
		<?php else : ?>
			<h3 class="woocommerce-noreviews"><?php esc_html_e( 'There are no reviews yet.', 'masterstudy' ); ?></h3>
		<?php endif; ?>
	</div>
	<div class="multiseparator"></div>

	<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>

		<div id="review_form_wrapper">
			<div id="review_form" class="stm_woo_review_form">
				<?php
					$commenter = wp_get_current_commenter();

					$comment_form = array(
						'title_reply'          => have_comments() ? __( 'Add a review', 'masterstudy' ) : sprintf( __( 'Be the first to review &ldquo;%s&rdquo;', 'masterstudy' ), get_the_title() ),
						'title_reply_to'       => __( 'Leave a Reply to %s', 'masterstudy' ),
						'comment_notes_before' => '',
						'comment_notes_after'  => '',
						'fields'               => array(
							'author' => '<div class="row">
								<div class="col-md-6 col-sm-6">
									<div class="form-group">
										<input class="form-control" id="author" name="author" type="text"
											value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"
											aria-required="true" placeholder="' . __( 'Name', 'masterstudy' ) . ' *" />
									</div>
								</div>
							</div>',
							'email'  => '<div class="col-md-6 col-sm-6">
								<div class="form-group">
									<input class="form-control" id="email" name="email" type="text"
										value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30"
										aria-required="true" placeholder="' . __( 'E-mail', 'masterstudy' ) . ' *" />
								</div>
							</div>',
						),
						'label_submit'         => __( 'Submit', 'masterstudy' ),
						'logged_in_as'         => '',
						'comment_field'        => '',
					);

					$account_page_url = wc_get_page_permalink( 'myaccount' );

					if ( $account_page_url ) {
						$comment_form['must_log_in'] = '<p class="must-log-in">' . sprintf( __( 'You must be <a href="%s">logged in</a> to post a review.', 'masterstudy' ), esc_url( $account_page_url ) ) . '</p>';
					}

					if ( 'yes' === get_option( 'woocommerce_enable_review_rating' ) ) {
						$comment_form['comment_field'] = '
						<p class="comment-form-rating woo_stm_rating_fields">
							<label for="rating">' . esc_html__( 'Your rating', 'masterstudy' ) . '</label>
							<select name="rating" id="rating" class="hidden"aria-required="true" required>
								<option value="">' . esc_html__( 'Rate&hellip;', 'masterstudy' ) . '</option>
								<option value="5">' . esc_html__( 'Perfect', 'masterstudy' ) . '</option>
								<option value="4">' . esc_html__( 'Good', 'masterstudy' ) . '</option>
								<option value="3">' . esc_html__( 'Average', 'masterstudy' ) . '</option>
								<option value="2">' . esc_html__( 'Not that bad', 'masterstudy' ) . '</option>
								<option value="1">' . esc_html__( 'Very poor', 'masterstudy' ) . '</option>
							</select>
						</p>';
					}

					$comment_form['comment_field'] .= '<div class="form-group"><textarea class="form-control" id="comment" name="comment" cols="45" rows="8" aria-required="true" placeholder ="' . __( 'Your Review', 'masterstudy' ) . ' *"></textarea></div>';

					comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) );
					?>
			</div>
		</div>
	<?php else : ?>
		<p class="woocommerce-verification-required"><?php esc_html_e( 'Only logged in customers who have purchased this product may leave a review.', 'masterstudy' ); ?></p>
	<?php endif; ?>
	<div class="clear"></div>
</div>
